==> keepassxc_2.4.3+dfsg.1.orig.tar.xz: keepassxc-2.4.3/share/macosx/Info.plist.cmake <==
<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE plist PUBLIC "-//Apple Computer//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
<plist version="1.0">
<dict>
  <key>NSPrincipalClass</key>
  <string>NSApplication</string>
  <key>CFBundleAllowMixedLocalizations</key>
  <true/>
  <key>CFBundleDevelopmentRegion</key>
  <string>English</string>
  <key>CFBundleDisplayName</key>
  <string>${PROJECT_NAME}</string>
  <key>CFBundleExecutable</key>
  <string>${PROGNAME}</string>
  <key>CFBundleIconFile</key>
  <string>keepassxc.icns</string>
  <key>CFBundleIdentifier</key>
  <string>org.keepassx.keepassxc</string>
  <key>CFBundleInfoDictionaryVersion</key>
  <string>6.0</string>
  <key>CFBundleName</key>
  <string>${PROJECT_NAME}</string>
  <key>CFBundlePackageType</key>
  <string>APPL</string>
  <key>CFBundleShortVersionString</key>
  <string>${KEEPASSXC_VERSION}</string>
  <key>CFBundleSignature</key>
  <string>KEPX</string>
  <key>CFBundleVersion</key>
  <string>${KEEPASSXC_VERSION_NUM}</string>
  <key>NSHumanReadableCopyright</key>
    <string>Copyright 2016-2018 KeePassXC Development Team</string>
    <key>CFBundleDocumentTypes</key>
    <array>
      <dict>
        <key>CFBundleTypeExtensions</key>
        <array>
          <string>kdbx</string>
        </array>
        <key>CFBundleTypeIconFile</key>
        <string>keepassxc.icns</string>
        <key>CFBundleTypeName</key>
        <string>KeePassXC Password Database</string>
        <key>CFBundleTypeOSTypes</key>
        <array>
          <string>kdbx</string>
        </array>
        <key>CFBundleTypeRole</key>
        <string>Editor</string>
      </dict>
    </array>
  </dict>
</plist>

==> keepassxc_2.7.10+dfsg1.orig.tar.xz: keepassxc-2.7.10/share/macosx/Info.plist.cmake <==
<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE plist PUBLIC "-//Apple Computer//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
<plist version="1.0">
<dict>
  <key>NSPrincipalClass</key>
  <string>NSApplication</string>
  <key>CFBundleAllowMixedLocalizations</key>
  <true/>
  <key>CFBundleDevelopmentRegion</key>
  <string>English</string>
  <key>CFBundleDisplayName</key>
  <string>${PROJECT_NAME}</string>
  <key>CFBundleExecutable</key>
  <string>${PROGNAME}</string>
  <key>CFBundleIconFile</key>
  <string>keepassxc.icns</string>
  <key>CFBundleIdentifier</key>
  <string>org.keepassxc.keepassxc</string>
  <key>CFBundleInfoDictionaryVersion</key>
  <string>6.0</string>
  <key>CFBundleName</key>
  <string>${PROJECT_NAME}</string>
  <key>CFBundlePackageType</key>
  <string>APPL</string>
  <key>CFBundleVersion</key>
  <string>${KEEPASSXC_VERSION}</string>
  <key>CFBundleShortVersionString</key>
  <string>${KEEPASSXC_VERSION}</string>
  <key>CFBundleSignature</key>
  <string>KPXC</string>
  <key>CFBundleVersion</key>
  <string>${KEEPASSXC_VERSION_NUM}</string>
  <key>NSHumanReadableCopyright</key>
    <string>Copyright 2016-2020 KeePassXC Development Team</string>
    <key>CFBundleDocumentTypes</key>
    <array>
      <dict>
        <key>CFBundleTypeExtensions</key>
        <array>
          <string>kdbx</string>
        </array>
        <key>CFBundleTypeIconFile</key>
        <string>keepassxc.icns</string>
        <key>CFBundleTypeName</key>
        <string>KeePassXC Password Database</string>
        <key>CFBundleTypeOSTypes</key>
        <array>
          <string>kdbx</string>
        </array>
        <key>CFBundleTypeRole</key>
        <string>Editor</string>
      </dict>
    </array>
  </dict>
</plist>
